Sensor Managers
===============

.. automodule:: stonesoup.sensormanager
    :no-members:

.. automodule:: stonesoup.sensormanager.base
    :show-inheritance:

.. automodule:: stonesoup.sensormanager.optimise
    :show-inheritance:
    :inherited-members:


Reward Functions
----------------
.. automodule:: stonesoup.sensormanager.reward
    :show-inheritance:
    :special-members:
